// PIC16F1827 Configuration Bit Settings

// 'C' source line config statements

#include <xc.h>

// #pragma config statements should precede project file includes.
// Use project enums instead of #define for ON and OFF.

// CONFIG1
#pragma config FOSC = INTOSC    // Oscillator Selection (INTOSC oscillator: I/O function on CLKIN pin)
#pragma config WDTE = OFF       // Watchdog Timer Enable (WDT disabled)
#pragma config PWRTE = ON       // Power-up Timer Enable (PWRT enabled)
#pragma config MCLRE = OFF      // MCLR Pin Function Select (MCLR/VPP pin function is digital input)
#pragma config CP = OFF         // Flash Program Memory Code Protection (Program memory code protection is disabled)
#pragma config CPD = OFF        // Data Memory Code Protection (Data memory code protection is disabled)
#pragma config BOREN = ON       // Brown-out Reset Enable (Brown-out Reset enabled)
#pragma config CLKOUTEN = OFF   // Clock Out Enable (CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin)
#pragma config IESO = OFF       // Internal/External Switchover (Internal/External Switchover mode is disabled)
#pragma config FCMEN = OFF      // Fail-Safe Clock Monitor Enable (Fail-Safe Clock Monitor is disabled)

// CONFIG2
#pragma config WRT = OFF        // Flash Memory Self-Write Protection (Write protection off)
#pragma config PLLEN = OFF      // PLL Enable (4x PLL disabled)
#pragma config STVREN = ON      // Stack Overflow/Underflow Reset Enable (Stack Overflow or Underflow will cause a Reset)
#pragma config BORV = LO        // Brown-out Reset Voltage Selection (Brown-out Reset Voltage (Vbor), low trip point selected.)
#pragma config LVP = OFF        // Low-Voltage Programming Enable (High-voltage on MCLR/VPP must be used for programming)

#define _XTAL_FREQ 8000000

void ma(void);

//割り込み処理
void interrupt intr(void) {
    TMR2IF = 0;//Clear Timer2 iterrupt flag
    RA0 ^= 1;//RA0 Invert
}

//メイン処理
main(){

    OSCCONbits.IRCF = 0b1110;//Internal Oscillator 8MHz
    ANSELA = 0b00000000;//All Digital I/O
    ANSELB = 0b00000000;//All Digital I/O
    TRISA  = 0b00000000;//All Output (RA5 is Input Only)
    TRISB  = 0b00000000;//All Output

    INTCONbits.GIE = 1;//Global Interrupt Enable bit
    INTCONbits.PEIE = 1;//Peripheral Interrupt Enable bit
    PIE1bits.TMR2IE = 1;//TMR2 to PR2 match interrupt
    T2CONbits.T2OUTPS = 0b0001;//Timer2 Postscaler Select bits (1:2)
    T2CONbits.TMR2ON = 0b1;//Timer2 On bit
    T2CONbits.T2CKPS = 0b00;//Timer2-type Clock Prescale Select bits (1)
    TMR2 = 0x00;//Timer2 Module register
    PR2 = 200;//Timer2 Period register

    while(1){
        PR2 = 190;
        __delay_ms(1000);
        ma();
        PR2 = 190;
        __delay_ms(750);
        ma();
        PR2 = 213;
        __delay_ms(250);
        ma();
        PR2 = 239;
        __delay_ms(1000);
        ma();
        PR2 = 239;
        __delay_ms(1000);
        ma();
        PR2 = 213;
        __delay_ms(1000);
        ma();
        PR2 = 213;
        __delay_ms(1000);
        ma();
        PR2 = 190;
        __delay_ms(750);
        ma();
        PR2 = 213;
        __delay_ms(250);
        ma();
        PR2 = 239;
        __delay_ms(1000);
    }
}

void ma(){
    T2CONbits.TMR2ON = 0;
    __delay_ms(50);
    T2CONbits.TMR2ON = 1;
}
